@@ -2,9 +2,11 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '1.025000'; # TRIAL
+$MetaCPAN::Client::VERSION = '2.004000'; # TRIAL
 use Moo;
 use Carp;
+use Ref::Util qw< is_arrayref is_hashref >;
+use URI::Escape qw< uri_escape_utf8 >;
 
 use MetaCPAN::Client::Request;
 use MetaCPAN::Client::Author;
@@ -31,23 +33,9 @@ my @supported_searches = qw<
 sub BUILDARGS {
     my ( $class, %args ) = @_;
 
-    # default 'domain' for 'version => v0|v1'
-    my $version = exists $ENV{METACPAN_VERSION} ? $ENV{METACPAN_VERSION} : undef;
-    $version  //= exists $args{version}         ? $args{version}         : undef;
-    if ( defined $version ) {
-        $version =~ s/^(?!v)/v/;
-        $version eq 'v0' or $version eq 'v1' or croak "invalid version number";
-        $args{domain} //=
-            $version eq 'v0' ? 'api.metacpan.org' :
-            $version eq 'v1' ? 'fastapi.metacpan.org' :
-            undef;
-        $args{version} = $version;
-    }
-
     $args{'request'} ||= MetaCPAN::Client::Request->new(
         ( ua      => $args{ua}      )x!! $args{ua},
         ( domain  => $args{domain}  )x!! $args{domain},
-        ( version => $args{version} )x!! $args{version},
     );
 
     return \%args;
@@ -102,7 +90,7 @@ sub favorite {
     my $args   = shift;
     my $params = shift;
 
-    ref($args) eq 'HASH'
+    is_hashref($args)
         or croak 'favorite takes a hash ref as parameter';
 
     return $self->_search( 'favorite', $args, $params );
@@ -113,7 +101,7 @@ sub rating {
     my $args   = shift;
     my $params = shift;
 
-    ref($args) eq 'HASH'
+    is_hashref($args)
         or croak 'rating takes a hash ref as parameter';
 
     return $self->_search( 'rating', $args, $params );
@@ -172,7 +160,7 @@ sub all {
         or croak "all: unsupported type";
     $type =~ s/s$//;
 
-    $params and ref($params) ne 'HASH'
+    $params and !is_hashref($params)
         and croak "all: params must be a hashref";
 
     return $self->$type( { __MATCH_ALL__ => 1 }, $params );
@@ -182,19 +170,36 @@ sub download_url {
     my $self   = shift;
     my $module = shift;
 
-    $self->request->version eq 'v0'
-        and croak "download_url: not supported in v0 (use version => v1)";
-
     return $self->_get( 'download_url', $module );
 }
 
+sub autocomplete {
+    my $self = shift;
+    my $q    = shift;
+
+    my $res;
+
+    eval {
+        $res = $self->fetch( '/search/autocomplete?q=' . uri_escape_utf8($q) );
+        1;
+
+    } or do {
+        warn $@;
+        return [];
+    };
+
+    return [
+        map { $_->{fields} } @{ $res->{hits}{hits} }
+    ];
+}
+
 ###
 
 sub _get {
     my $self = shift;
 
     ( scalar(@_) == 2
-      or ( scalar(@_) == 3 and ( !defined $_[2] or ref $_[2] eq 'HASH' ) ) )
+      or ( scalar(@_) == 3 and ( !defined $_[2] or is_hashref($_[2]) ) ) )
         or croak '_get takes type and search string as parameters (and an optional params hash)';
 
     my $type   = shift;
@@ -206,7 +211,7 @@ sub _get {
     my $response = $self->fetch(
         sprintf("%s/%s%s", $type ,$arg, $fields_filter||'')
     );
-    ref $response eq 'HASH'
+    is_hashref($response)
         or croak sprintf( 'Failed to fetch %s (%s)', ucfirst($type), $arg );
 
     $type = 'DownloadURL' if $type eq 'download_url';
@@ -223,7 +228,7 @@ sub _read_fields {
     my $fields = delete $params->{fields};
     $fields or return;
 
-    if ( ref $fields eq 'ARRAY' ) {
+    if ( is_arrayref($fields) ) {
         grep { ref $_ } @$fields
             and croak "fields array should not contain any refs.";
 
@@ -243,10 +248,10 @@ sub _search {
     my $args   = shift;
     my $params = shift;
 
-    ref $args eq 'HASH'
+    is_hashref($args)
         or croak '_search takes a hash ref as query';
 
-    ! defined $params or ref $params eq 'HASH'
+    ! defined $params or is_hashref($params)
         or croak '_search takes a hash ref as query parameters';
 
     $params ||= {};
@@ -268,7 +273,7 @@ sub _get_or_search {
     my $arg    = shift;
     my $params = shift;
 
-    ref $arg eq 'HASH' and
+    is_hashref($arg) and
         return $self->_search( $type, $arg, $params );
 
     defined $arg and ! ref($arg)
@@ -366,7 +371,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 1.025000
+version 2.004000
 
 =head1 SYNOPSIS
 
@@ -382,8 +387,6 @@ version 1.025000
     use MetaCPAN::Client;
 
     my $mcpan = MetaCPAN::Client->new(
-      version => 'v1',
-
       ua => HTTP::Tiny::Mech->new(
         mechua => WWW::Mechanize::Cached->new(
           cache => CHI->new(
@@ -417,12 +420,6 @@ instead of the default, which is L<HTTP::Tiny>.
 Then it can be used to fetch the user agent object used by
 L<MetaCPAN::Client::Request>.
 
-=head2 version
-
-API version (supported: 'v0', 'v1')
-
-This will also set default value to your 'domain' (unless given)
-
 =head2 domain
 
 If given, will be used to alter the API domain.
@@ -515,6 +512,14 @@ on a given module, returned as L<MetaCPAN::Client::ResultSet>.
 
 Alias to C<reverse_dependencies> described above.
 
+=head2 autocomplete
+
+    my $ac = $mcpan->autocomplete('Danc');
+
+Call the search/autocomplete endpoint with a query string.
+
+Returns an array reference.
+
 =head2 recent
 
     my $recent = $mcpan->recent(10);
@@ -533,6 +538,14 @@ formats (html, plain, x_pod & x_markdown).
     my $pod = $mcpan->pod('Moo')->html;
     my $pod = $mcpan->pod('Moo', { url_prefix => $prefix })->html;
 
+=head2 download_url
+
+Retrieve information from the 'download_url' endpoint
+
+    my $download_url = $mcpan->download_url('Moose')
+
+Returns a L<MetaCPAN::Client::DownloadURL> object
+
 =head2 all
 
 Retrieve all matches for authors/modules/distributions/favorites or releases.
@@ -542,14 +555,6 @@ Retrieve all matches for authors/modules/distributions/favorites or releases.
 When called with a second parameter containing a hash ref,
 will support the following keys:
 
-=head2 download_url
-
-Retrieve information from the 'download_url' endpoint (v1 only)
-
-    my $download_url = $mcpan->download_url('Moose')
-
-Returns a L<MetaCPAN::Client::DownloadURL> object
-
 =head3 fields
 
 See SEARCH PARAMS.
