@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Distribution;
 # ABSTRACT: A Distribution data object
-$MetaCPAN::Client::Distribution::VERSION = '1.025000'; # TRIAL
+$MetaCPAN::Client::Distribution::VERSION = '2.004000'; # TRIAL
 use Moo;
 
 with 'MetaCPAN::Client::Role::Entity';
@@ -13,22 +13,35 @@ my %known_fields = (
     hashref  => [qw< bugs river >]
 );
 
-my @known_fields =
-    map { @{ $known_fields{$_} } } qw< scalar arrayref hashref >;
+my %__known_fields_ex = (
+    map { my $k = $_; $k => +{ map { $_ => 1 } @{ $known_fields{$k} } } }
+    keys %known_fields
+);
 
-foreach my $field (@known_fields) {
+my @known_fields = map { @{ $known_fields{$_} } } keys %known_fields;
+
+foreach my $field ( @known_fields ) {
     has $field => (
         is      => 'ro',
         lazy    => 1,
         default => sub {
             my $self = shift;
-            return $self->data->{$field};
+            return (
+                exists $self->data->{$field}                ? $self->data->{$field} :
+                exists $__known_fields_ex{hashref}{$field}  ? {} :
+                exists $__known_fields_ex{arrayref}{$field} ? [] :
+                exists $__known_fields_ex{scalar}{$field}   ? '' :
+                undef
+            );
         },
     );
 }
 
 sub _known_fields { return \%known_fields }
 
+sub rt     { $_[0]->bugs->{rt}     || {} }
+sub github { $_[0]->bugs->{github} || {} }
+
 1;
 
 __END__
@@ -43,7 +56,7 @@ MetaCPAN::Client::Distribution - A Distribution data object
 
 =head1 VERSION
 
-version 1.025000
+version 2.004000
 
 =head1 SYNOPSIS
 
@@ -65,6 +78,16 @@ Hash-Ref.
 
 Hash-Ref.
 
+=head1 METHODS
+
+=head2 rt
+
+Returns 'bugs.rt' hash ref (defaults to {}).
+
+=head2 github
+
+Returns 'bugs.github' hash ref (defaults to {}).
+
 =head1 AUTHORS
 
 =over 4
