@@ -2,46 +2,37 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '1.025000'; # TRIAL
+$MetaCPAN::Client::Request::VERSION = '2.004000'; # TRIAL
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
-use Search::Elasticsearch;
-use Try::Tiny;
 use HTTP::Tiny;
-use Ref::Util qw< is_hashref >;
+use Ref::Util qw< is_arrayref is_hashref >;
+
+use MetaCPAN::Client::Scroll;
+use MetaCPAN::Client::Types qw< HashRef >;
+
+has _clientinfo => (
+    is      => 'ro',
+    isa     => HashRef,
+    lazy    => 1,
+    builder => '_build_clientinfo',
+);
 
 has domain => (
     is      => 'ro',
     default => sub {
-        return ( $ENV{METACPAN_DOMAIN} ? $ENV{METACPAN_DOMAIN} : 'api.metacpan.org' );
+        $ENV{METACPAN_DOMAIN} and return $ENV{METACPAN_DOMAIN};
+        $_[0]->_clientinfo->{production}{domain};
     },
 );
 
-has version => (
-    is       => 'ro',
-    required => 1,
-    default  => sub {
-        my $info = $_[0]->_clientinfo;
-        $info->{production}{version};
-    },
-);
-
-has _clientinfo => (
-    is      => 'ro',
-    isa     => sub {
-        is_hashref( $_[0] ) or croak '_clientinfo mush be a hashref';
-    },
-    lazy    => 1,
-    builder => '_build_clientinfo',
-);
-
 has base_url => (
     is      => 'ro',
     lazy    => 1,
     default => sub {
-        my $self = shift;
-        return sprintf('https://%s/%s', $self->domain, $self->version);
+        $ENV{METACPAN_DOMAIN} and return $ENV{METACPAN_DOMAIN};
+        $_[0]->_clientinfo->{production}{url};
     },
 );
 
@@ -71,11 +62,17 @@ has _is_agg => (
     writer  => '_set_is_agg'
 );
 
+sub BUILDARGS {
+    my ( $self, %args ) = @_;
+    $args{domain} and $args{base_url} = $args{domain};
+    return \%args;
+}
+
 sub _build_ua {
     my $self = shift;
 
     # This level of indirection is so that if a user has not specified a custom UA
-    # MetaCPAN::Client and ElasticSearch will have their own UA's
+    # MetaCPAN::Client will have its own UA's
     #
     # But if the user **has** specified a custom UA, that UA is used for both.
     if ( $self->_has_user_ua ) {
@@ -101,7 +98,8 @@ sub _build_clientinfo {
     }
     or $info = +{
         production => {
-            version => 'v0'  # last known production version
+            url => 'https://fastapi.metacpan.org/v1/', # last known production url
+            domain => 'https://fastapi.metacpan.org/'  # last known production domain
         }
     };
 
@@ -128,23 +126,12 @@ sub ssearch {
     my $args   = shift;
     my $params = shift;
 
-    my $es = Search::Elasticsearch->new(
-        nodes            => [ 'https://' . $self->domain ],
-        cxn_pool         => 'Static::NoPing',
-        send_get_body_as => 'POST',
-        ( $self->_has_user_ua ? ( handle => $self->_user_ua ) : () )
-    );
-
-    my $body = $self->_build_body($args, $params);
-
-    my $scroller = $es->scroll_helper(
-        ( search_type => 'scan' ) x !$self->_is_agg,
-        scroll      => '5m',
-        index       => $self->version,
-        type        => $type,
-        size        => 1000,
-        body        => $body,
-        %{ $params },
+    my $scroller = MetaCPAN::Client::Scroll->new(
+        ua       => $self->ua,
+        size     => 500,
+        base_url => $self->base_url,
+        type     => $type,
+        body     => $self->_build_body($args, $params),
     );
 
     return $scroller;
@@ -155,7 +142,7 @@ sub _decode_result {
     my $result = shift;
     my $url    = shift or croak 'Second argument of a URL must be provided';
 
-    ref $result eq 'HASH'
+    is_hashref($result)
         or croak 'First argument must be hashref';
 
     my $success = $result->{'success'};
@@ -173,8 +160,12 @@ sub _decode_result {
     $url =~ m|/source/| and return $content;
 
     my $decoded_result;
-    try   { $decoded_result = decode_json $content }
-    catch { croak "Couldn't decode '$content': $_" };
+    eval {
+        $decoded_result = decode_json $content;
+        1;
+    } or do {
+        croak "Couldn't decode '$content': $@";
+    };
 
     return $decoded_result;
 }
@@ -191,7 +182,6 @@ sub _build_body {
     return +{
         query => $query,
         _read_filters($params),
-        $self->_read_facets($params),
         $self->_read_aggregations($params)
     };
 }
@@ -202,17 +192,6 @@ my %key2es = (
     not    => 'must_not',
 );
 
-sub _read_facets {
-    my $self   = shift;
-    my $params = shift;
-
-    my $facets = delete $params->{facets};
-    ref($facets) or return ();
-
-    $self->_set_is_agg(1);
-    return ( facets => $facets );
-}
-
 sub _read_aggregations {
     my $self   = shift;
     my $params = shift;
@@ -235,15 +214,15 @@ sub _read_filters {
 
 sub _build_query_rec {
     my $args  = shift;
-    ref $args eq 'HASH' or croak 'query args must be a hash';
+    is_hashref($args) or croak 'query args must be a hash';
 
     my %query = ();
     my $basic_element = 1;
 
   KEY: for my $k ( qw/ all either not / ) {
         my $v = delete $args->{$k} || next KEY;
-        ref $v eq 'HASH'  and $v = [ $v ];
-        ref $v eq 'ARRAY' or croak "invalid value for key $k";
+        is_hashref($v)  and $v = [ $v ];
+        is_arrayref($v) or croak "invalid value for key $k";
 
         undef $basic_element;
 
@@ -291,7 +270,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 1.025000
+version 2.004000
 
 =head1 ATTRIBUTES
 
@@ -301,15 +280,7 @@ version 1.025000
 
 What domain to use for all requests.
 
-Default: B<api.metacpan.org>.
-
-=head2 version
-
-    $mcpan = MetaCPAN::Client->new( version => 'v0' );
-
-What version of MetaCPAN should be used?
-
-Default: B<v0>.
+Default: B<https://fastapi.metacpan.org>.
 
 =head2 base_url
 
@@ -317,10 +288,10 @@ Default: B<v0>.
         base_url => 'https://localhost:9999/v2',
     );
 
-Instead of overriding the C<base_url>, you should override the C<domain> and
-C<version>. The C<base_url> will be set appropriately automatically.
+Instead of overriding the C<base_url>, you should override the C<domain>.
+The C<base_url> will be set appropriately automatically.
 
-Default: I<https://$domain/$version>.
+Default: I<https://$domain>.
 
 =head2 ua
 
@@ -361,6 +332,8 @@ Default: user agent string: B<MetaCPAN::Client/$version>.
 
 =head1 METHODS
 
+=head2 BUILDARGS
+
 =head2 fetch
 
     my $result = $mcpan->fetch('/release/Moose');
@@ -375,8 +348,8 @@ Fetches a path from MetaCPAN (post or get), and returns the decoded result.
 
 =head2 ssearch
 
-Calls an Elastic Search query (using L<Search::Elasticsearch> and returns an
-L<Search::Elasticsearch::Scroll> scroller object.
+Calls an ElasticSearch query and returns an L<MetaCPAN::Client::Scroll>
+scroller object.
 
 =head1 AUTHORS
 
