@@ -2,10 +2,11 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '1.025000'; # TRIAL
+$MetaCPAN::Client::ResultSet::VERSION = '2.004000'; # TRIAL
 use Moo;
 use Carp;
-use Ref::Util qw< is_arrayref >;
+
+use MetaCPAN::Client::Types qw< ArrayRef >;
 
 has type => (
     is       => 'ro',
@@ -22,8 +23,8 @@ has scroller => (
     is        => 'ro',
     isa       => sub {
         use Safe::Isa;
-        $_[0]->$_isa('Search::Elasticsearch::Scroll')
-            or croak 'scroller must be an Search::Elasticsearch::Scroll object';
+        $_[0]->$_isa('MetaCPAN::Client::Scroll')
+            or croak 'scroller must be an MetaCPAN::Client::Scroll object';
     },
     predicate => 'has_scroller',
 );
@@ -31,10 +32,7 @@ has scroller => (
 # in case we're returning from a fetch
 has items => (
     is  => 'ro',
-    isa => sub {
-        ref $_[0] eq 'ARRAY'
-            or croak 'items must be an array ref';
-    },
+    isa => ArrayRef,
 );
 
 has total => (
@@ -70,12 +68,6 @@ sub next {
     return $class->new_from_request( $result->{'_source'} || $result->{'fields'} );
 }
 
-sub facets {
-    my $self = shift;
-
-    return $self->has_scroller ? $self->scroller->facets : {};
-}
-
 sub aggregations {
     my $self = shift;
 
@@ -97,19 +89,19 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 1.025000
+version 2.004000
 
 =head1 DESCRIPTION
 
 Object representing a result from Elastic Search. This is used for the complex
 (as in L<non-simple/MetaCPAN::Client/"SEARCH SPEC">) queries to MetaCPAN. It
-provides easy access to the scroller and facets.
+provides easy access to the scroller and aggregations.
 
 =head1 ATTRIBUTES
 
 =head2 scroller
 
-An L<Search::Elasticsearch::Scroll> object.
+An L<MetaCPAN::Client::Scroll> object.
 
 =head2 items
 
@@ -139,10 +131,6 @@ The entity of the result set. Available types:
 
 The aggregations available in the Elastic Search response.
 
-=head2 facets
-
-The facets available in the Elastic Search response.
-
 =head1 METHODS
 
 =head2 next
